==> xwiki-rendering-api-6.4.8-sources.jar: org/xwiki/rendering/internal/wiki/WikiModelProvider.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.wiki;

import javax.inject.Inject;
import javax.inject.Provider;

import org.xwiki.component.manager.ComponentLookupException;
import org.xwiki.component.manager.ComponentManager;
import org.xwiki.rendering.wiki.WikiModel;

/**
 * Used to find out if an implementation of {@link WikiModel} is available or not at runtime. In non wiki mode all
 * image and link references are considered as URLs or Paths.
 *
 * @version $Id: f42946a71cdbdeb8a70726759fed5df053600b73 $
 * @since 5.2M1
 */
public class WikiModelProvider implements Provider<WikiModel>
{
    /**
     * Used to verify if we're in wiki mode or not by looking up an implementation of
     * {@link org.xwiki.rendering.wiki.WikiModel}. In non wiki mode all image references are considered as URLs.
     */
    @Inject
    private ComponentManager componentManager;

    @Override
    public WikiModel get()
    {
        WikiModel wikiModel;
        try {
            wikiModel = this.componentManager.getInstance(WikiModel.class);
        } catch (ComponentLookupException e) {
            wikiModel = null;
        }
        return wikiModel;
    }
}

==> xwiki-rendering-api-11.1-rc-1-sources.jar: org/xwiki/rendering/internal/wiki/WikiModelProvider.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.wiki;

import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Provider;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.component.manager.ComponentLookupException;
import org.xwiki.component.manager.ComponentManager;
import org.xwiki.rendering.wiki.WikiModel;

/**
 * Helper provider to find out if the WikiModel implementation exists or not.
 *
 * @version $Id: 3ca81d8732a50a524732d8a1455fd55e8253edbb $
 * @since 9.6RC1
 */
@Component
@Singleton
public class WikiModelProvider implements Provider<WikiModel>
{
    @Inject
    @Named("context")
    private Provider<ComponentManager> componentManagerProvider;

    @Override
    public WikiModel get()
    {
        WikiModel wikiModel;

        // Try to find a WikiModel implementation and set it if it can be found. If not it means we're in
        // non wiki mode and the reference parameter will have no effect.
        try {
            wikiModel = this.componentManagerProvider.get().getInstance(WikiModel.class);
        } catch (ComponentLookupException e) {
            // There's no WikiModel implementation available.
            wikiModel = null;
        }

        return wikiModel;
    }
}
